/*
 * GaugeConsumer.java
 *
 * Created on November 5, 2001, 11:19 AM
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/GaugeConsumer.java,v 1.2 2002/01/31 16:39:01 schmerl Exp $
 * $Log: GaugeConsumer.java,v $
 * Revision 1.2  2002/01/31 16:39:01  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure;
import edu.cmu.cs.able.gaugeInfrastructure.util.*;
/** The GaugeConsumer interface must be implemented by classes
 * that are intended to create, control, and/or listen to gauges.
 * The methods in this interface define the callbacks that
 * are invoked when gauges report values or information about
 * their status.
 *
 * @author schmerl
 * @version 1.1
 */
public interface GaugeConsumer {

    /** The callback invoked when a gauge reports a single value.
     * @param gauge The Gauge that reported the value.
     * @param valueName The name of the value (according to the gauge)
     * @param propertyName The property name that the value is associated with.
     * The property is the interpretation of the value
     * according to a high level model. This association is
     * established when the gauge is created.
     * @param value The value reported by the gauge.
     */    
    public void onReportValue(GaugeControl gauge, String valueName, String propertyName, String value);
    
    /** The callback invoked when a gauge reports multiple values
     * in a single reporting action.
     * @param gauge Theg gauge reporting the value
     * @param values The values reported. Each element of the vector is a
     * (valueName, propertyName, value) tuple.
     */    
    public void onReportMultipleValues(GaugeControl gauge, GaugeValueVector values);
    
    /** The callback invoked when a gauge has been configured.
     * Because a gauge can have multiple consumers, all consumers
     * must know when a gauge has been reconfigured. The gauge
     * announces this when any consumer configures it.
     * @param gauge The gauge that was configured.
     * @param configParams The new configuration parameters for the gauge.
     */    
    public void onReportConfigured(GaugeControl gauge, StringPairVector configParams);
    
    /** The callback invoked when a gauge is deleted by (another) consumer.
     * After this callback is invoked, the gauge consumer can expect
     * no more events (or callbacks) from this particular gauge.
     * @param gauge The gauge that was deleted.
     */    
    public void onReportDeleted(GaugeControl gauge);
    
    /** The callback invoked when a gauge is created.
     * @param gauge The gauge that was created.
     */    
    public void onReportCreated(GaugeControl gauge);
    
}

