/*
 * GaugeControl.java
 *
 * Created on November 2, 2001, 11:46 AM
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/GaugeControl.java,v 1.2 2002/01/31 16:39:01 schmerl Exp $
 * $Log: GaugeControl.java,v $
 * Revision 1.2  2002/01/31 16:39:01  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure;
import edu.cmu.cs.able.gaugeInfrastructure.Events.*;
import edu.cmu.cs.able.gaugeInfrastructure.util.*;
/** The GaugeControl interface specifies the point-to-point
 * control interface for a gauge. Each gauge must
 * implement this interface. Each infrastructure implementation
 * will likely include two implementations of this interface -
 * an handle that can be used by consumers to control the gauge
 * and a gauge that is the actual gauge implementation.
 * @author Bradley Schmerl (schmerl@cs.cmu.edu)
 * @version 1.1
 */
public interface GaugeControl {

    /** Each gauge implementation must have an ID
     * @return The ID of the gauge
     */    
    public GaugeID getGaugeID();
    
    /** The method called when configuring a gauge.
     * @param configParams The configuration parameters for the gauge as (name, value) pairs.
     * @return <B>true</B> if the gauge could be configured successfully; <B>false</B> otherwise
     */    
    public boolean configure(StringPairVector configParams);
    
    /** The method called to query the state of the gauge
     * @param setupParams Will be filled with the parameters with which the gauge was setup, as (name, value) pairs.
     * @param configParams Will be filled with the current configuration of the gauge, as (name, value) pairs
     * @param mappings Will be filled with the mappings for the gauge, as (name, propertyName) pairs.
     * @return <B>true</B> if the gauge successfully returns its state; <B>false</B> otherwise
     */    
    public boolean queryState(StringPairVector setupParams, StringPairVector configParams, StringPairVector mappings);
    
    /** Called when a gauge is queried for a value. This provides an
     * alternative to the gauge reporting events.
     * @param valueName The name of the value to be queried.
     * @return The value corresponding to the name passed in; <B>null</B> indicates that the gauge value could not be determined.
     */    
    public String queryValue(String valueName);
    
    /** Returns all the gauge values that the gauge reports.
     * @param values This is filled with all the values as a (valueName, propertyName, value) tuple
     * @return <B>true</B> if the values were successfully determined; <B>false</B> otherwise.
     */    
    public boolean queryAllValues(GaugeValueVector values);
    

    
}

