/*
 * GaugeMgr.java
 *
 * Created on November 2, 2001, 12:05 PM
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/GaugeMgr.java,v 1.3 2002/05/13 14:42:17 zensoul Exp $
 * $Log: GaugeMgr.java,v $
 * Revision 1.3  2002/05/13 14:42:17  zensoul
 * no message
 *
 * Revision 1.2  2002/01/31 16:39:01  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure;
import edu.cmu.cs.able.gaugeInfrastructure.util.*;
/** This interface is implemented by Gauge Managers, and allows
 * a gauge to be created and deleted, or the type information
 * about a gauge to be queried.
 *
 * @author Bradley Schmerl (schmerl@cs.cmu.edu)
 * @version 1.1
 */
public interface GaugeMgr {

    /** Each gauge manager has a unique ID.
     * @return The identifier of the gauge manager.
     */    
    public String getGaugeMgrID ();
    
    /** Creates a new gauge with the information specified.
     * @param gauge The ID of the gauge to be created.
     * @param setupParams The parameters with which to set up the gauge.
     * @param mappings The mappings of values to model properties for how
     * the gauge should report values.
     * @return A new {@link GaugeControl} interface. Note that the {@link GaugeID} of this GaugeControl may be different to the {@link GaugeID} passed in as paramters.
     * In particular, the modelName and uid may be different.
     */    
    public GaugeControl createGauge(GaugeID gauge, StringPairVector setupParams, StringPairVector mappings);
   
    /** Determines whether this gauge manager can manage gauges of
     * a particular type.
     * @param gaugeType The type of the gauge being queried
     * @return <B>true</B> if the gauge manager managers this type; <B>false</B> otherwise.
     */    
    public boolean managesType(String gaugeType);
    
    /** Deletes a gauge. A gauge will send out a final delete announcement
     * so that all consumers can be informed.
     * @param gauge The gauge to be deleted.
     * @return <B>true</B> if the gauge was deleted; <B>false</B> otherwise.
     */    
    public boolean deleteGauge(GaugeControl gauge);
    
    /** Fills in the type information for a gauge type.
     * @param gaugeType The type of the gauge for which information is being queried.
     * @param configParamsMeta Filled in with the parameters that can be used to configure a gauge as <I>(name, type)</I> pairs.
     * @param valuesMeta Filled in with the values that the gauge can report, as <I>(name, type)</I> pairs.
     * @return <B>true</B> if the information could be determined; <B>false</B> otherwise.
     */    
    public boolean queryMetaInfo(String gaugeType, StringPairVector configParamsMeta, StringPairVector valuesMeta);
    
}

