/*
 * GaugeReportingBus.java
 *
 * Created on November 2, 2001, 11:52 AM
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/GaugeReportingBus.java,v 1.2 2002/01/31 16:39:02 schmerl Exp $
 * $Log: GaugeReportingBus.java,v $
 * Revision 1.2  2002/01/31 16:39:02  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure;
import edu.cmu.cs.able.gaugeInfrastructure.util.*;
import edu.cmu.cs.able.gaugeInfrastructure.*;
import edu.cmu.cs.able.gaugeInfrastructure.Events.*;
/** The gauge reporting bus is the bus on which a gauge reports events.
 *
 * @author Bradley Schmerl (schmerl@cs.cmu.edu)
 * @version 1.1
 */
public interface GaugeReportingBus {

    /** Called by a gauge when it reports a value. How often
     * the gauge reports these values is determined by the gauge
     * (although, it may be controlled through setup or configuration).
     * @param gauge The gauge reporting the value.
     * @param valueName The name of the value.
     * @param propertyName The property with which the value is associated (established when the gauge is created)
     * @param value The value being reported.
     * @return whether the value was reported successfully.
     */    
    public boolean reportValue(GaugeID gauge, String valueName, String propertyName, String value);
    
    /** Called by a gauge when it reports multiple values. How often
     * the gauge reports these values is determined by the gauge
     * (although, it may be controlled through setup or configuration).
     * @param gauge The gauge reporting the values.
     * @param values The values being reported - as <I>(valueName, propertyName, value)</I> tuples.
     * @return <B>true</B> if the values where successfully reported; <B>false</B> otherwise.
     */    
    public boolean reportMultipleValues(GaugeID gauge, GaugeValueVector values);
    
    /** Called when a gauge has been configured. This should always be
     * called when a guage is configured through its {@link GaugeControl} interface
     * to let other interested parties know.
     * @param gauge The gauge being configured.
     * @param configParams The new configuration of the gauge - as <I>(name, value)</I> pairs.
     * @return Whether the configuration was reported successfully.
     */    
    public boolean reportConfigured(GaugeID gauge, StringPairVector configParams);
    
    /** This event is sent as the last act of the gauge before it is
     * destroyed. It lets all interested parties know that the gauge
     * will no longer report values.
     * @param gauge The ID of the gauge being deleted.
     * @return Whether the deletion was reported successfully.
     */    
    public boolean reportDeleted(GaugeID gauge);
    
    /** The first event produced by the gauge. It lets interested
     * parties know that a new gauge is about to report on the
     * bus.
     * @param gauge The ID of the new gauge.
     * @return Whether the report was successfully sent.
     */    
    public boolean reportCreated(GaugeID gauge);
    
    /** Called when an interested party is wants reports in some pattern.
     * Depending on the underlying implementation, this could allow browsers
     * to register for any creation events, for example.
     * @param event The event pattern to subscribe to.
     * @param subscriber The object that contains a callback to call if the event pattern is matched.
     */    
    public void subscribeToGaugeEvent(GaugeEvent event, Subscriber subscriber);
    
    /** Called to unregister a subscriber's interest in a gauge event pattern.
     * @param event The event pattern to unsubscribe from. If this is <B>null</B>, then the
     * subscriber is unsubscribed from all events.
     * @param subscriber The subscriber to unsubscribe.
     */    
    public void unsubscribeToGaugeEvent(GaugeEvent event, Subscriber subscriber);
}

