/*
 * GaugeID.java
 *
 * Created on November 2, 2001, 11:32 AM
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/util/GaugeID.java,v 1.5 2002/07/11 14:35:59 schmerl Exp $
 * $Log: GaugeID.java,v $
 * Revision 1.5  2002/07/11 14:35:59  schmerl
 * Changed equality to ignore empty UIDs
 *
 * Revision 1.4  2002/06/21 13:29:16  schmerl
 * no message
 *
 * Revision 1.3  2002/05/13 14:37:58  zensoul
 * Added a retryCnt field to class to allow recording how many creation retries have elapsed.
 * Made changes to equal() and toString().
 *
 * Revision 1.2  2002/01/31 16:39:09  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure.util;

/** This class is captures the identification for a gauge.
 * @author Bradley Schmerl
 * @version 1.1
 */
public class GaugeID implements java.io.Serializable {

    /** The unique identifier of this gauge
     */    
    public String uid = null;
    
    /** The gauge's name
     */    
    public String gaugeName = null;
    
    /** The gauge's type
     */    
    public String gaugeType = null;
    
    /** The model that this gauge is attached to
     */    
    public String modelName = null;
    
    /** The type of the model that this gauge is attached to
     */    
    public String modelType = null;
    
    /** Number of retries so far to create this particular gauge
     */
    public Integer retryCnt = new Integer (0); // default to no retries yet

    /** Creates new GaugeID */
    public GaugeID() {
    }

    /** Transfers one gauge's ID into this ID.
     * @param gid The ID of the gauge to be transferred
     */    
    public void xferGaugeID (GaugeID gid) {
        uid = gid.uid;
        gaugeName = gid.gaugeName;
        gaugeType = gid.gaugeType;
        modelName = gid.modelName; 
        modelType = gid.modelType;
        retryCnt = gid.retryCnt;
    }
    
    /** Returns whether the two GaugeID's are equal
     * @param obj The GaugeID for comparison
     * @return Whether the gauges are equal
     */    
    public boolean equals(java.lang.Object obj) {
        GaugeID comp = (GaugeID )obj;
        return ((uid != null) && (comp.uid != null) && uid.length () != 0 && comp.uid.length () != 0 && (uid.equals (comp.uid))) ||
               (gaugeName.equals (comp.gaugeName) && gaugeType.equals (comp.gaugeType) && 
                modelName.equals (comp.modelName) && modelType.equals (comp.modelType) &&
                retryCnt.equals (comp.retryCnt));
    }
    
    /** Returns a string representation of the GaugeID
     * @return The string representation
     */    
    public java.lang.String toString() {
        return "UID: " + uid + ", gauge( " + gaugeName + " : " + gaugeType + 
               "), model( " + modelName + " : " + modelType + " : " + retryCnt + ")";
    }
    
}
