/*
 * GaugeValueVector.java
 *
 * Created on November 2, 2001, 11:53 AM
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/util/GaugeValueVector.java,v 1.2 2002/01/31 16:39:09 schmerl Exp $
 * $Log: GaugeValueVector.java,v $
 * Revision 1.2  2002/01/31 16:39:09  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure.util;

import java.io.*;
import java.util.*;
/**
 *
 * @author  schmerl
 * @version 
 */

class GaugeValue implements java.io.Serializable {
    /** The name of this value
     */    
    public String valueName;
    /** The propertyName that is associated with this value
     */    
    public String propertyName;
    /** The actual value
     */    
    public String value;
    
    /**
     * @param name
     * @param property
     * @param value  */    
    public GaugeValue (String name, String property, String value) {
        valueName = name;
        propertyName = property;
        this.value = value;
    }
}

  /** GaugeValueVector provides vector operations using GaugeValue as element
    data store.
 **/
public class GaugeValueVector implements java.io.Serializable {
	// the data store for GaugeValue objects	
	private Vector tupleVector = new Vector(4, 4);
	
	/** Returns the number of elements in this vector
         * @return the number of gauge value records in the vector
         */
	public int size() {
		return tupleVector.size();
	}
	
	/** Returns whether the vector is empty
         * @return true if no gauge value in the vector, false otherwise.
         */
	public boolean isEmpty() {
		return tupleVector.isEmpty();
	}
	
	/** Create new gauge value record and add to the vector.
	    @param name the name of the new gauge value
	    @param property the property name that the gauge value will 
		associate with
	    @param value the actual value represented as String
	 **/
	public void addElement(String name, String property, String value){
		GaugeValue sp = new GaugeValue(name, property, value);
		tupleVector.addElement(sp);			
	}
	
	/** Add an existing GaugeValue object into the vector
         * @param sp The GaugeValue to be added
         */
	public void addElement(GaugeValue sp){		
		tupleVector.addElement(sp);
	}
	
	/** Returns a GaugeValue at a given index
         * @return the GaugeValue object at the given index
         * @param index the index of the object to be retrieved
         */
	public GaugeValue elementAt(int index){
		return (GaugeValue)(tupleVector.elementAt(index));
	}
	
	/** Remove the GaugaValue object at the given index
	    @param index the index of the object to be removed
	 **/
	public void removeElementAt(int index){
		tupleVector.removeElementAt(index);
		return;
	}
	
	/** Remove all object in the vector.
	 **/
	public void removeAllElements(){
		tupleVector.removeAllElements();
		return;
	}
	
	/** Retrieve the name of the gauge value at given index
	    @return the gauge value's name
	    @param index the index of the object
         **/
	public String nameAt(int index){
		return ((GaugeValue)(tupleVector.elementAt(index))).valueName;
	};
	
	/** Retrieve the value of the gauge value at given index
	    @return the gauge value's value
	    @param index the index of the object
         **/
	public String valueAt(int index){
		return ((GaugeValue)(tupleVector.elementAt(index))).value;
	};	
	
	/** Retrieve the name of property that associates with the gauge value
	    @return the gauge value's value
	    @param index the index of the object
         **/
	public String propertyAt(int index){
		return 
		  ((GaugeValue)(tupleVector.elementAt(index))).propertyName;
	};
	
	/** Retrieve the value represented as String given its value name
	    @param name the name of the gauge value
	    @return the value represented as String
	 **/ 
	public String getValue(String name){
		String value = null;
		for (int i=0; i<tupleVector.size(); i++) 
			if ( 0==( (GaugeValue)tupleVector.elementAt(i)).valueName.compareTo(name) )
				return ((GaugeValue)tupleVector.elementAt(i)).value;			
		return value;
	};
	
	/** Retrieve the name of the proprety that associates with the value.
	    @param name the name of the gauge value
	    @return the name of the associated property
	 **/ 
	public String getProperty(String name){
		String value = null;
		for (int i=0; i<tupleVector.size(); i++) 
			if ( 0==((GaugeValue)tupleVector.elementAt(i)).valueName.compareTo(name) )
				return ((GaugeValue)tupleVector.elementAt(i)).propertyName;			
		return value;
	};
	
        /**
         * Copy the elements from this into gvv
         * @param   gvv the GaugeValueVector to copy into
         **/
        public void copyInto (GaugeValueVector gvv) {
            for (int i = 0; i < size (); i++) {
                gvv.addElement (nameAt (i), propertyAt (i), valueAt (i));
            }
        }
        
	/** Convert the vector into a string so that it can be printed
	    @return the string that represents the GaugeValueVector
	 **/ 
	public String toString(){
		String newStr = new String("GaugeValue:");
		for (int i=0; i<size(); i++){
			newStr += new String("\n\t" + nameAt(i));
			newStr += new String("\t" + propertyAt(i));
			newStr += new String("\t" + valueAt(i));
		}
		newStr += new String("\n");
		return newStr;
	}
	


}
