/**
 * Global provides some useful static helper functions.
 * @author      Hong Yan
 * @author      Bradley Schmerl
 * @version     1.0
 * @since       JDK1.3.1
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/util/Global.java,v 1.3 2002/01/31 16:39:09 schmerl Exp $
 * $Log: Global.java,v $
 * Revision 1.3  2002/01/31 16:39:09  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure.util;

import java.net.*;
import java.util.*;
import java.io.*;
import java.rmi.*;
import javax.swing.*;


class ProcessTrace implements Runnable {
    private String cmd;
    private Process p;
    private BufferedReader br;
    ProcessTrace(String cmd) {
        this.cmd = cmd;
    }
    
    public Process getProcess() {
        int i = 5;
        while (p == null && i-- > 0) {
            try {
                Thread.sleep (1000);
            }
            catch (Exception e) {
            }
        }
        return p;
    }
    
    public void run() {
        String s = null;
        try {
            p  = Runtime.getRuntime().exec(this.cmd);
            System.out.println(p.toString()+" started");
            System.out.flush();
            //br = new BufferedReader(new InputStreamReader(p.getErrorStream()));
            br = new BufferedReader(new InputStreamReader(p.getInputStream()));
            //p.waitFor();
            while ((s = br.readLine()) != null) {
                //System.err.println(s);
                //System.err.flush();
                System.out.println(s);
                System.out.flush();
            }
            br.close();
        }
        catch (Exception e) {
            e.printStackTrace();
        }
    }
}

public class Global {
    /**
     * Initialize look and feel.
     */
    public static void initLookAndFeel(String theLookAndFeel) { 
        if (theLookAndFeel != null) {
            if (theLookAndFeel.equals("Metal")) {
                theLookAndFeel = UIManager.getCrossPlatformLookAndFeelClassName();
            } else if (theLookAndFeel.equals("System")) {
                theLookAndFeel = UIManager.getSystemLookAndFeelClassName();
            } else if (theLookAndFeel.equals("Mac")) {
                theLookAndFeel = "com.sun.java.swing.plaf.mac.MacLookAndFeel";
            } else if (theLookAndFeel.equals("Windows")) {
                theLookAndFeel = "com.sun.java.swing.plaf.windows.WindowsLookAndFeel";
            } else if (theLookAndFeel.equals("Motif")) {
                theLookAndFeel = "com.sun.java.swing.plaf.motif.MotifLookAndFeel";
            }
        }
        
        try {
            UIManager.setLookAndFeel(theLookAndFeel);
        } catch (Exception e) {
            //e.printStackTrace();
        }
    }
    
    /**
     * Get the host list from a file.
     * @param   fileName            name of the host list file
     * @param   hostName            name of the host
     * @return                      list of the port and address of the host
     */
    public static Vector getHostList(String fileName, String hostName) {
        Vector hostList = new Vector();
        String aLine = new String();
        StringTokenizer st;
        String name, host, port;
        
        try {
            RandomAccessFile raf = new RandomAccessFile(fileName, "r");
            
            while (raf.getFilePointer() < raf.length()) {
                aLine = raf.readLine();
                st = new StringTokenizer(aLine, " ");
                name = st.nextToken();
                host = st.nextToken();
                port = st.nextToken();
                host = java.net.InetAddress.getByName(host).getHostAddress();
                host = host + ":" + port;
                if (name.equals(hostName)) {
                    hostList.addElement(host);
                    //System.out.println(hostList.toString());
                }
            }
        }
        catch (Exception e) {
            e.printStackTrace();
        }
        return hostList;
    }
    
    /**
     * Generate a Unique ID.
     * @return                      generated Unique ID
     */
    public static String generateUID() {
        long ip; //the 0-63th bit
        long t;  //the 64-127 bit
        try {
            byte[] ipa=java.net.InetAddress.getLocalHost().getAddress();
            ip=(long)(""+ipa[0]+ipa[1]).hashCode();
            ip=ip<<32 | ((long)(""+ipa[2]+ipa[3]).hashCode());
        } catch (java.net.UnknownHostException e) {
            ip=(long)(Math.random()*(Long.MAX_VALUE));
        }
        t=System.currentTimeMillis();
        String sip=Long.toHexString(ip);
        while (sip.length()<16)
            sip="0"+sip;
        String st=Long.toHexString(t);
        while (st.length()<16)
            st="0"+st;
        String ret=sip+st;
        ret=ret.substring(0,8)+"-"+ret.substring(8,12)+"-"+ret.substring(12,16)+"-"+ret.substring(16,20)+"-"+ret.substring(20);
        return ret;
        
    }
    
    public static int generatePort() {
        long ct = System.currentTimeMillis();
        int t;  //the 64-127 bit
        t = (int)(ct%(49151-1024)+1025);
        return t;
        
    }
    
    public static String generateUniqueID() {
        return generateUID ();
/*        Date d = new Date();
        InetAddress addr;
        try {
            addr = InetAddress.getLocalHost();
        }
        catch (java.net.UnknownHostException ex) {
            return "unknown@" + d.toString();
        }
        return addr.getHostAddress() + "@" + d.toString();
 **/
    }
    
    public static String getHost() {
        InetAddress addr;
        try {
            addr = InetAddress.getLocalHost();
        }
        catch (java.net.UnknownHostException ex) {
            return "localhost";
        }
        return addr.getHostAddress();
    }
    
    public static boolean match(GaugeID src, GaugeID dst) {
        return ((src.uid.equals("") || dst.uid.equals("") || src.equals(dst.uid))
        ||
        (src.gaugeName.equals("") || dst.gaugeName.equals("") || src.gaugeName.equals(dst.gaugeName))
        &&
        (src.gaugeType.equals("") || dst.gaugeType.equals("") || src.gaugeType.equals(dst.gaugeType))
        &&
        (src.modelName.equals("") || dst.modelName.equals("") || src.modelName.equals(dst.modelName))
        &&
        (src.modelType.equals("") || dst.modelType.equals("") || src.modelType.equals(dst.modelType)));
    }
    
    public static Process exec(String cmd) {
        ProcessTrace pt = new ProcessTrace(cmd);
        new Thread(pt).start();
        return pt.getProcess();
    }
    
    public static boolean debugFlag = false;
    
    public static void debug(String out) {
        if (debugFlag) {
            System.err.println(out);
        }
    }
}
