/**
* The <code>StringObjectVector</code> class implements a growable array of 
* string pairs. Like an array, it contains components that can be 
* accessed using an integer index. However, the size of a <code>StringObjectVector</code>
* can grow or shrink as needed to accommodate adding and removing items after
* the <code>StringObjectVector</code> has been created.
* @author		Hong Yan
* @author 		Bradley Schmerl
* @version		1.0
* @since		JDK1.3.1
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/util/StringObjectVector.java,v 1.2 2002/01/31 16:39:10 schmerl Exp $
 * $Log: StringObjectVector.java,v $
 * Revision 1.2  2002/01/31 16:39:10  schmerl
 * Added CVS header information
 *
*/

package edu.cmu.cs.able.gaugeInfrastructure.util;

import java.io.*;
import java.util.Vector;
import java.util.Enumeration;

class StringObject implements java.io.Serializable
{
	public String name; 
	public Object value;
	
	public StringObject(String name, Object value){
		this.name = name;
		this.value = value;
	}
}

public class StringObjectVector implements java.io.Serializable
{	
	private Vector pairVector = new Vector(4, 4);
	
    /**
    * Returns the number of components in this vector.
    * @return  the number of components in this vector.
    */
	public int size() {
		return pairVector.size();
	}
	
	/**
    * Tests if this vector has no components.
	* @return  <code>true</code> if and only if this vector has 
	*          no components, that is, its size is zero;
	*          <code>false</code> otherwise.
	*/
	public boolean isEmpty() {
		return pairVector.isEmpty();
	}
	
	public Enumeration elements() {
		return pairVector.elements();
	}
	
    /**
    * Adds the specified component to the end of this vector, 
    * increasing its size by one. The capacity of this vector is 
    * increased if its size becomes greater than its capacity.
    * @param   name		   the name of the pair to be added.
    * @param   value	   the value of the pair to be added.
    */
	public void addElement(String name, Object value){
		StringObject sp = new StringObject(name, value);
		pairVector.addElement(sp);			
	}
	
    /**
    * Adds the specified component to the end of this vector, 
    * increasing its size by one. The capacity of this vector is 
    * increased if its size becomes greater than its capacity.
    * @param   StringObject		   the pair to be added.
    */
	public void addElement(StringObject sp){		
		pairVector.addElement(sp);
	}
	
    /**
    * Returns the component at the specified index.
    * @param      index   an index into this vector.
    * @return     the pair at the specified index.
    */
	public StringObject elementAt(int index){
		return (StringObject)(pairVector.elementAt(index));
	}
	
    /**
    * Removes the first (lowest-indexed) occurrence of the argument 
    * from this vector. If the object is found in this vector, each 
    * component in the vector with an index greater or equal to the 
    * object's index is shifted downward to have an index one smaller 
    * than the value it had previously.
    * @param   index		   the index to be deleted.
    */
	public void removeElementAt(int index){
		pairVector.removeElementAt(index);
		return;
	}

    /**
    * Removes the first (lowest-indexed) occurrence of the argument 
    * from this vector. If the object is found in this vector, each 
    * component in the vector with an index greater or equal to the 
    * object's index is shifted downward to have an index one smaller 
    * than the value it had previously.
    * @param   name		   	the name of the pair to be deleted.
    */
	public void removeElement(String name){
		for (int i = 0; i < size(); i++) {
			if (nameAt(i).equals(name))
				removeElementAt(i);
		}
		return;
	}
	
    /**
    * Removes all components from this vector and sets its size to zero.
    */
	public void removeAllElements(){
		pairVector.removeAllElements();
		return;
	}
	
    /**
    * Gets the value of a specified pair in this vector.
    * @param   name			   name of the pair.
	* @return				   value of the pair.
    */
	public Object getValue(String name){
		Object value = null;
		for (int i=0; i<pairVector.size(); i++) {
			if ( ((StringObject)pairVector.elementAt(i)).name.equals(name) )
				return ((StringObject)pairVector.elementAt(i)).value;			
		}
		return value;
	};
	
    /**
    * Sets the value of a specified pair in this vector.
    * @param	name			   name of the pair.
	* @param	value			   value of the pair.
    */
	public void setValue(String name, Object value){		
		for (int i=0; i<pairVector.size(); i++) {
			if ( ((StringObject)pairVector.elementAt(i)).name.equals(name) )
				((StringObject)pairVector.elementAt(i)).value = value;
		}
		// name not present
		addElement(name, value);	
	};
	
    /**
    * Gets the name of a specified pair in this vector. <p>
    * @param	index				index of the pair.
	* @return						name of the pair.
    */
	public String nameAt(int index){
		return ((StringObject)pairVector.elementAt(index)).name;
	};
	
    /**
    * Gets the value of a specified pair in this vector. <p>
    * @param	index				index of the pair.
	* @return						value of the pair.
    */
	public Object valueAt(int index){
		return ((StringObject)pairVector.elementAt(index)).value;
	};
	

    /**
    * Returns a string representation of this Vector, containing
    * the String representation of each element.
    */
	public String toString(){
		String newStr = new String("StringObjectVector:");
		for (int i=0; i<size(); i++){
			newStr += new String("\n\t" + nameAt(i));
			newStr += new String("\t" + valueAt(i).toString());
		}
		newStr += new String("\n");
		return newStr;
	};
}