/*
 * StringPairVector.java
 *
 * Created on November 2, 2001, 11:36 AM
 * $Header: D:/Projects/Repository/GaugeAPI/edu/cmu/cs/able/gaugeInfrastructure/util/StringPairVector.java,v 1.3 2002/01/31 16:39:10 schmerl Exp $
 * $Log: StringPairVector.java,v $
 * Revision 1.3  2002/01/31 16:39:10  schmerl
 * Added CVS header information
 *
 */

package edu.cmu.cs.able.gaugeInfrastructure.util;

/**
 *
 * @author  schmerl
 * @version 
 */
import java.io.*;
import java.util.Vector;
import java.util.Enumeration;

class StringPair implements java.io.Serializable {
    /**
     */    
    public String name;
    public String value;
    
    public StringPair (String name, String value) {
        this.name = name;
        this.value = value;
    }
}

public class StringPairVector implements java.io.Serializable {

    private Vector pairVector = new Vector (4,4);
    /** Creates new StringPairVector */
    
        /**
    * Returns the number of components in this vector.
    * @return  the number of components in this vector.
    */
    public int size() {
        return pairVector.size();
    }
    
    /**
    * Tests if this vector has no components.
    * @return  <code>true</code> if and only if this vector has 
    *          no components, that is, its size is zero;
    *          <code>false</code> otherwise.
    */
    public boolean isEmpty() {
        return pairVector.isEmpty();
    }

        /** returns all the elements as an Enumeration
         * @return The enumeration of all the elements.
         */        
    public Enumeration elements() {
        return pairVector.elements();
    }
    
    /**
    * Adds the specified component to the end of this vector, 
    * increasing its size by one. The capacity of this vector is 
    * increased if its size becomes greater than its capacity.
    * @param   name        the name of the pair to be added.
    * @param   value       the value of the pair to be added.
    */
    public void addElement(String name, String value){
        StringPair sp = new StringPair(name, value);
        pairVector.addElement(sp);          
    }
    
        /** Adds the specified component to the end of this vector,
         * increasing its size by one. The capacity of this vector is
         * increased if its size becomes greater than its capacity.
         * @param sp The element to add
         */
    public void addElement(StringPair sp){      
        pairVector.addElement(sp);
    }
    
    /**
    * Returns the component at the specified index.
    * @param      index   an index into this vector.
    * @return     the pair at the specified index.
    */
    public StringPair elementAt(int index){
        return (StringPair)(pairVector.elementAt(index));
    }
    
    /**
    * Removes the first (lowest-indexed) occurrence of the argument 
    * from this vector. If the object is found in this vector, each 
    * component in the vector with an index greater or equal to the 
    * object's index is shifted downward to have an index one smaller 
    * than the value it had previously.<p>
    * @param   index           the index to be deleted.
    */
    public void removeElementAt(int index){
        pairVector.removeElementAt(index);
        return;
    }
    
    /**
    * Removes all components from this vector and sets its size to zero.
    */
    public void removeAllElements(){
        pairVector.removeAllElements();
        return;
    }
    
    /**
    * Gets the value of a specified pair in this vector.
    * @param   name            name of the pair.
    * @return                  value of the pair.
    */
    public String getValue(String name){
        String value = null;
        for (int i=0; i<pairVector.size(); i++) {
            if ( 0==((StringPair)pairVector.elementAt(i)).name.compareTo(name) )
                return ((StringPair)pairVector.elementAt(i)).value;         
        }
        return value;
    };
    
    /**
    * Sets the value of a specified pair in this vector.
    * @param    name               name of the pair.
    * @param    value              value of the pair.
    */
    public void setValue(String name, String value){        
        for (int i=0; i<pairVector.size(); i++) {
            if ( 0==((StringPair)pairVector.elementAt(i)).name.compareTo(name) ) {
                ((StringPair)pairVector.elementAt(i)).value = value;
                return;
            }
        }
        // name not present
        addElement(name, value);    
    };

    /**
    * Sets the value of a specified pair in this vector. <p>
    * @param    index              index of the pair.
    * @param    value              value of the pair.
    */
    public void setValue(int index, String value){      
        if (index >= pairVector.size()) return;
        ((StringPair)pairVector.elementAt(index)).value = value;
    };
    
    /**
    * Gets the name of a specified pair in this vector. <p>
    * @param    index               index of the pair.
    * @return                       name of the pair.
    */
    public String nameAt(int index){
        return ((StringPair)pairVector.elementAt(index)).name;
    };
    
    /**
    * Gets the value of a specified pair in this vector. <p>
    * @param    index               index of the pair.
    * @return                       value of the pair.
    */
    public String valueAt(int index){
        return ((StringPair)pairVector.elementAt(index)).value;
    };
        
    /**
     * Copies the values contained in this into the StringPairVector passed in.<p>
     * @param   spv The StringPairVector to copy elements into
     **/
        public void copyInto (StringPairVector spv) {
            for (int i = 0; i < size (); i++) {
                spv.addElement (nameAt (i), valueAt (i));
            }
        }

        /**
         * Returns a string representation of this Vector, containing
         * the String representation of each element.
         * @return The string representation
         */
    public String toString(){
        String newStr = new String("StringPairVector:");
        for (int i=0; i<size(); i++){
            newStr += new String("\n\t" + nameAt(i));
            newStr += new String("\t" + valueAt(i));
        }
        newStr += new String("\n");
        return newStr;
    };
        
        public boolean equals (Object comp) {
            if (!comp.getClass ().equals (this.getClass ())) return false;
            StringPairVector spv = (StringPairVector )comp;
            if (spv.size () != this.size ()) return false;
            boolean equals = true;
            for (int i = 0; i < this.size () && equals; i++) {
                if (!this.nameAt (i).equals (spv.nameAt (i)) || !this.valueAt (i).equals (spv.valueAt (i))) {
                    equals = false;
                }
            }
            return equals;
            
            
        }

}
